@@ -1,7 +1,7 @@
 """
 Type annotations for dynamodb service ServiceResource
 
-[Open documentation](./service_resource.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
 
 Usage::
 
@@ -65,8 +65,8 @@ __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection"
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
-    [Show boto3-stubs documentation](./service_resource.md#serviceresourcetablescollection)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#serviceresourcetablescollection)
     """
 
     def all(self) -> "ServiceResourceTablesCollection":
@@ -92,7 +92,7 @@ class ServiceResourceTablesCollection(ResourceCollection):
 
 class Table(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)[Show boto3-stubs documentation](./service_resource.md#table)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#table)
     """
 
     attribute_definitions: List[Any]
@@ -120,18 +120,19 @@ class Table(Boto3ServiceResource):
 
     def batch_writer(self, overwrite_by_pkeys: List[str] = None) -> BatchWriter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
-        [Show boto3-stubs documentation](./service_resource.md#tablebatch_writermethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablebatch_writer-method)
         """
 
     def delete(self) -> DeleteTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.delete)
-        [Show boto3-stubs documentation](./service_resource.md#tabledeletemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete-method)
         """
 
     def delete_item(
         self,
+        *,
         Key: Dict[
             str,
             Union[
@@ -176,21 +177,22 @@ class Table(Boto3ServiceResource):
                 Dict[str, Any],
                 None,
             ],
-        ] = None,
+        ] = None
     ) -> DeleteItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
-        [Show boto3-stubs documentation](./service_resource.md#tabledelete_itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete_item-method)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
-        [Show boto3-stubs documentation](./service_resource.md#tableget_available_subresourcesmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget_available_subresources-method)
         """
 
     def get_item(
         self,
+        *,
         Key: Dict[
             str,
             Union[
@@ -214,21 +216,22 @@ class Table(Boto3ServiceResource):
         ConsistentRead: bool = None,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ProjectionExpression: str = None,
-        ExpressionAttributeNames: Dict[str, str] = None,
+        ExpressionAttributeNames: Dict[str, str] = None
     ) -> GetItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.get_item)
-        [Show boto3-stubs documentation](./service_resource.md#tableget_itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget_item-method)
         """
 
     def load(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.load)
-        [Show boto3-stubs documentation](./service_resource.md#tableloadmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableload-method)
         """
 
     def put_item(
         self,
+        *,
         Item: Dict[
             str,
             Union[
@@ -273,15 +276,16 @@ class Table(Boto3ServiceResource):
                 Dict[str, Any],
                 None,
             ],
-        ] = None,
+        ] = None
     ) -> PutItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.put_item)
-        [Show boto3-stubs documentation](./service_resource.md#tableput_itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableput_item-method)
         """
 
     def query(
         self,
+        *,
         IndexName: str = None,
         Select: SelectType = None,
         AttributesToGet: List[str] = None,
@@ -333,21 +337,22 @@ class Table(Boto3ServiceResource):
                 Dict[str, Any],
                 None,
             ],
-        ] = None,
+        ] = None
     ) -> QueryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.query)
-        [Show boto3-stubs documentation](./service_resource.md#tablequerymethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablequery-method)
         """
 
     def reload(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.reload)
-        [Show boto3-stubs documentation](./service_resource.md#tablereloadmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablereload-method)
         """
 
     def scan(
         self,
+        *,
         IndexName: str = None,
         AttributesToGet: List[str] = None,
         Limit: int = None,
@@ -398,30 +403,32 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ] = None,
-        ConsistentRead: bool = None,
+        ConsistentRead: bool = None
     ) -> ScanOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.scan)
-        [Show boto3-stubs documentation](./service_resource.md#tablescanmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablescan-method)
         """
 
     def update(
         self,
+        *,
         AttributeDefinitions: List["AttributeDefinitionTypeDef"] = None,
         BillingMode: BillingModeType = None,
         ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
         GlobalSecondaryIndexUpdates: List[GlobalSecondaryIndexUpdateTypeDef] = None,
         StreamSpecification: "StreamSpecificationTypeDef" = None,
         SSESpecification: SSESpecificationTypeDef = None,
-        ReplicaUpdates: List[ReplicationGroupUpdateTypeDef] = None,
+        ReplicaUpdates: List[ReplicationGroupUpdateTypeDef] = None
     ) -> "_Table":
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.update)
-        [Show boto3-stubs documentation](./service_resource.md#tableupdatemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate-method)
         """
 
     def update_item(
         self,
+        *,
         Key: Dict[
             str,
             Union[
@@ -468,23 +475,23 @@ class Table(Boto3ServiceResource):
                 Dict[str, Any],
                 None,
             ],
-        ] = None,
+        ] = None
     ) -> UpdateItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.update_item)
-        [Show boto3-stubs documentation](./service_resource.md#tableupdate_itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate_item-method)
         """
 
     def wait_until_exists(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
-        [Show boto3-stubs documentation](./service_resource.md#tablewait_until_existsmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait_until_exists-method)
         """
 
     def wait_until_not_exists(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
-        [Show boto3-stubs documentation](./service_resource.md#tablewait_until_not_existsmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait_until_not_exists-method)
         """
 
 
@@ -493,15 +500,15 @@ _Table = Table
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.ServiceResource)[Show boto3-stubs documentation](./service_resource.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.ServiceResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
     """
 
     tables: ServiceResourceTablesCollection
 
     def Table(self, name: str) -> _Table:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
-        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcetablemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcetable-method)
         """
 
     def batch_get_item(
@@ -510,23 +517,25 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
     ) -> BatchGetItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
-        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcebatch_get_itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch_get_item-method)
         """
 
     def batch_write_item(
         self,
+        *,
         RequestItems: Dict[str, List["WriteRequestTypeDef"]],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None
     ) -> BatchWriteItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
-        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcebatch_write_itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch_write_item-method)
         """
 
     def create_table(
         self,
+        *,
         AttributeDefinitions: List["AttributeDefinitionTypeDef"],
         TableName: str,
         KeySchema: List["KeySchemaElementTypeDef"],
@@ -536,15 +545,15 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
         StreamSpecification: "StreamSpecificationTypeDef" = None,
         SSESpecification: SSESpecificationTypeDef = None,
-        Tags: List["TagTypeDef"] = None,
+        Tags: List["TagTypeDef"] = None
     ) -> _Table:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
-        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcecreate_tablemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcecreate_table-method)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.82/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
-        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourceget_available_subresourcesmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourceget_available_subresources-method)
         """
